import Link from "next/link"
import { Button } from "@/components/ui/button"
import { Film, Check, Video, Award, Clock, ArrowRight } from "lucide-react"
import Image from "next/image"

export default function LandingPage() {
  return (
    <div className="flex min-h-screen flex-col">
      <header className="sticky top-0 z-40 w-full border-b bg-background/95 backdrop-blur supports-[backdrop-filter]:bg-background/60">
        <div className="container flex h-16 items-center space-x-4 sm:justify-between sm:space-x-0">
          <div className="flex gap-2 items-center text-xl font-bold">
            <Film className="h-6 w-6" />
            <span>VideoEditPro</span>
          </div>
          <div className="flex flex-1 items-center justify-end space-x-4">
            <Button asChild>
              <Link href="https://www.fiverr.com/users/esaseoservices" target="_blank" rel="noopener noreferrer">
                Hire Me Now
              </Link>
            </Button>
          </div>
        </div>
      </header>
      <main className="flex-1">
        <section className="w-full py-12 md:py-24 lg:py-32 xl:py-48">
          <div className="container px-4 md:px-6">
            <div className="grid gap-6 lg:grid-cols-[1fr_400px] lg:gap-12 xl:grid-cols-[1fr_600px]">
              <div className="flex flex-col justify-center space-y-4">
                <div className="space-y-2">
                  <h1 className="text-3xl font-bold tracking-tighter sm:text-5xl xl:text-6xl/none">
                    Professional Video Editing Services
                  </h1>
                  <p className="max-w-[600px] text-muted-foreground md:text-xl">
                    Transform your raw footage into stunning, professional videos that captivate your audience and
                    elevate your brand.
                  </p>
                </div>
                <div className="flex flex-col gap-2 min-[400px]:flex-row">
                  <Button size="lg" asChild className="px-8">
                    <Link href="https://www.fiverr.com/users/esaseoservices" target="_blank" rel="noopener noreferrer">
                      Get Started Today <ArrowRight className="ml-2 h-4 w-4" />
                    </Link>
                  </Button>
                </div>
              </div>
              <Image
                src="/placeholder.svg?height=550&width=550"
                width={550}
                height={550}
                alt="Video editing workspace with professional equipment"
                className="mx-auto aspect-video overflow-hidden rounded-xl object-cover sm:w-full lg:order-last"
                priority
              />
            </div>
          </div>
        </section>

        <section className="w-full py-12 md:py-24 lg:py-32 bg-muted">
          <div className="container px-4 md:px-6">
            <div className="flex flex-col items-center justify-center space-y-4 text-center">
              <div className="space-y-2">
                <h2 className="text-3xl font-bold tracking-tighter sm:text-5xl">Expert Video Editing Services</h2>
                <p className="max-w-[900px] text-muted-foreground md:text-xl/relaxed lg:text-base/relaxed xl:text-xl/relaxed">
                  From color grading to motion graphics, I deliver high-quality video edits tailored to your specific
                  needs.
                </p>
              </div>
            </div>
            <div className="mx-auto grid max-w-5xl items-center gap-6 py-12 md:grid-cols-2 lg:grid-cols-3">
              <div className="flex flex-col items-center space-y-2 rounded-lg border p-6 shadow-sm">
                <Video className="h-12 w-12 text-primary" />
                <h3 className="text-xl font-bold">Content Creation</h3>
                <p className="text-center text-muted-foreground">
                  YouTube videos, social media content, and promotional videos that engage your audience.
                </p>
              </div>
              <div className="flex flex-col items-center space-y-2 rounded-lg border p-6 shadow-sm">
                <Clock className="h-12 w-12 text-primary" />
                <h3 className="text-xl font-bold">Fast Turnaround</h3>
                <p className="text-center text-muted-foreground">
                  Quick delivery without compromising on quality to meet your deadlines.
                </p>
              </div>
              <div className="flex flex-col items-center space-y-2 rounded-lg border p-6 shadow-sm">
                <Award className="h-12 w-12 text-primary" />
                <h3 className="text-xl font-bold">Premium Quality</h3>
                <p className="text-center text-muted-foreground">
                  Professional-grade editing that makes your videos stand out from the competition.
                </p>
              </div>
            </div>
          </div>
        </section>

        <section className="w-full py-12 md:py-24 lg:py-32">
          <div className="container px-4 md:px-6">
            <div className="grid gap-10 md:gap-16 lg:grid-cols-2">
              <div>
                <div className="space-y-4">
                  <h2 className="text-3xl font-bold tracking-tighter md:text-4xl/tight">
                    Why Choose My Video Editing Services?
                  </h2>
                  <p className="text-muted-foreground md:text-xl">
                    I deliver high-quality video edits that help you achieve your goals and connect with your audience.
                  </p>
                </div>
                <div className="mt-8 grid gap-4">
                  <div className="flex items-start gap-4">
                    <Check className="h-6 w-6 text-primary" />
                    <div>
                      <h3 className="font-bold">Attention to Detail</h3>
                      <p className="text-muted-foreground">Every frame is carefully crafted for maximum impact.</p>
                    </div>
                  </div>
                  <div className="flex items-start gap-4">
                    <Check className="h-6 w-6 text-primary" />
                    <div>
                      <h3 className="font-bold">Unlimited Revisions</h3>
                      <p className="text-muted-foreground">
                        I work until you're completely satisfied with the final product.
                      </p>
                    </div>
                  </div>
                  <div className="flex items-start gap-4">
                    <Check className="h-6 w-6 text-primary" />
                    <div>
                      <h3 className="font-bold">Affordable Pricing</h3>
                      <p className="text-muted-foreground">Professional quality editing at competitive rates.</p>
                    </div>
                  </div>
                </div>
              </div>
              <div className="flex flex-col justify-center space-y-4">
                <div className="rounded-lg border bg-background p-8 shadow-sm">
                  <div className="space-y-4">
                    <h3 className="text-2xl font-bold">Ready to transform your videos?</h3>
                    <p className="text-muted-foreground">
                      Click below to visit my Fiverr profile and let's discuss your project needs.
                    </p>
                    <Button size="lg" className="w-full" asChild>
                      <Link
                        href="https://www.fiverr.com/users/esaseoservices"
                        target="_blank"
                        rel="noopener noreferrer"
                      >
                        Visit My Fiverr Profile
                      </Link>
                    </Button>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </section>
      </main>
      <footer className="w-full border-t py-6">
        <div className="container flex flex-col items-center justify-center gap-4 md:flex-row md:gap-8">
          <p className="text-center text-sm leading-loose text-muted-foreground md:text-left">
            © {new Date().getFullYear()} VideoEditPro. All rights reserved.
          </p>
          <div className="flex items-center gap-4">
            <Link
              href="https://www.fiverr.com/users/esaseoservices"
              target="_blank"
              rel="noopener noreferrer"
              className="text-sm text-muted-foreground hover:underline"
            >
              Fiverr Profile
            </Link>
          </div>
        </div>
      </footer>
    </div>
  )
}

